@@ -1,5 +1,5 @@
-var whatsApp = require('electron').remote.getGlobal("whatsApp");
-var pjson = require('electron').remote.getGlobal('pjson');
+var whatsApp = require('@electron/remote').getGlobal("whatsApp");
+var pjson = require('@electron/remote').getGlobal('pjson');
 
 $(document).ready(() => {
     $("#appversion").html(pjson["version"]);
