@@ -55,6 +55,11 @@
         }
     })
 
+    // Needed for @electron/remote to work.
+    app.on('browser-window-created', (_, window) => {
+        require("@electron/remote/main").enable(window.webContents)
+    })
+
     if (!isAlreadyLocked) {
         app.quit()
     }
@@ -515,7 +520,7 @@
             })
 
             // Setting User Agent
-            var userAgent = 'Mozilla/5.0 (X11; Linux x86_64; rv:101.0) Gecko/20100101 Firefox/101.0'
+            var userAgent = 'Mozilla/5.0 (X11; Linux x86_64; rv:141.0) Gecko/20100101 Firefox/141.0'
 
             // Pick a random user agent from agents.json
             if (agents.userAgents) {
@@ -789,7 +794,9 @@
                     "center": true,
                     "frame": true,
                     "webPreferences": {
-                      "nodeIntegration": true,
+                        "nodeIntegration": true, 
+                        "contextIsolation": false,
+                        "enableRemoteModule": true,
                     }
                 }
             )
